@@ -137,13 +137,9 @@ class DesktopNotifier:
         self._impl = impl_cls(app_name, app_icon, notification_limit)
         self._did_request_authorisation = False
 
-        try:
-            self._loop = asyncio.get_event_loop()
-        except RuntimeError:
-            # If we are running in a thread, create a new event loop. Use the default
-            # event loop policy so that we don't interfere with anything set in the main
-            # thread.
-            self._loop = default_event_loop_policy.new_event_loop()
+        # Use our own event loop for the sync API so that we don't interfere with any
+        # other ansycio event loops / threads, etc.
+        self._loop = default_event_loop_policy.new_event_loop()
 
     def _run_coro_sync(self, coro: Coroutine[None, None, T]) -> T:
         """
@@ -215,8 +211,19 @@ class DesktopNotifier:
         thread: Optional[str] = None,
     ) -> Notification:
         """
-        Sends a desktop notification. Some arguments may be ignored, depending on the
-        backend.
+        Sends a desktop notification.
+
+        Some arguments may be ignored, depending on the backend.
+
+        This method will always return a :class:`base.Notification` instance and will
+        not raise an exception when scheduling the notification fails. If the
+        notification was scheduled successfully, its ``identifier`` will be set to the
+        platform's native notification identifier. Otherwise, the ``identifier`` will be
+        ``None``.
+
+        Note that even a successfully scheduled notification may not be displayed to the
+        user, depending on their notification center settings (for instance if "do not
+        disturb" is enabled on macOS).
 
         :param title: Notification title.
         :param message: Notification message.
